searchData={"items":[{"type":"module","title":"PubSubx","doc":"`PubSubx` is a simple publish-subscribe (PubSub) system built on top of Elixir's `GenServer` and `Registry`.\n\nThe module allows processes to subscribe to topics, publish messages to those topics, and manage subscriptions. It efficiently handles message delivery to subscribed processes and automatically cleans up subscriptions when processes terminate.","ref":"PubSubx.html"},{"type":"module","title":"Features - PubSubx","doc":"- **Subscribe/Unsubscribe:** Processes can subscribe or unsubscribe from topics.\n- **Publish:** Messages can be published to a topic, and all subscribers to that topic will receive the message.\n- **Dynamic Topics:** Topics are dynamically created as they are subscribed to, and they are removed when no subscribers exist.\n- **Process Monitoring:** Automatically removes subscribers when the process is no longer alive.","ref":"PubSubx.html#module-features"},{"type":"module","title":"Auto module - PubSubx","doc":"`PubSubx.Auto` module is an utility mod that helps developers to use less code for your PubSubx module definition.","ref":"PubSubx.html#module-auto-module"},{"type":"module","title":"Example Usage with Auto mod - PubSubx","doc":"Define an PubSubx module\n\n```elixir\ndefmodule MyApp.MyPubSub do\n  use PubSubx.Auto, name: MyPubSub\nend\n```\n\nInclude it in your supervisor tree\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      # Start the PubSubx server\n      {MyApp.MyPubSub, []}\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nNow you can use the MyPubSub module: \n\n```elixir\n# if you didn't use supervisor tree, you can start it as follow\n{:ok, _pid} = MyApp.MyPubSub.start_link()\n\n# subscribe a pid (eg: self()) to a topic\nMyApp.MyPubSub.subscribe(:my_topic, self())\n\n# list subscribers\nsubscribers = MyApp.MyPubSub.subscribers(:my_topic)\n\n# list topics\ntopics = MyApp.MyPubSub.topics()\n\n# publish a message\nMyApp.MyPubSub.publish(:my_topic, \"Hello, world!\")\n\n# Unsubscribe a process from a topic\n# This is optional. This happens automatically if the subscribed process dies.\nMyApp.MyPubSub.unsubscribe(:my_topic, self())\n```","ref":"PubSubx.html#module-example-usage-with-auto-mod"},{"type":"module","title":"Example Usage - PubSubx","doc":"Start the PubSubx server:\n\n    {:ok, pid} = PubSubx.start_link(name: :my_pubsub)\n\nSubscribe a process to a topic:\n\n    PubSubx.subscribe(:my_topic, self(), :my_pubsub)\n\nPublish a message to the topic:\n\n    PubSubx.publish(:my_topic, \"Hello, subscribers!\", :my_pubsub)\n\nGet the list of subscribers:\n\n    subscribers = PubSubx.subscribers(:my_topic, :my_pubsub)\n\nUnsubscribe a process from a topic:\n\n    PubSubx.unsubscribe(:my_topic, self(), :my_pubsub)","ref":"PubSubx.html#module-example-usage"},{"type":"function","title":"PubSubx.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"PubSubx.html#child_spec/1"},{"type":"function","title":"PubSubx.publish/3","doc":"Publishes a message to the specified `topic`.\n\nAll subscribers to that `topic` will receive the `message`.\n\nIf a `name` is not provided, it defaults to the `PubSubx` module name.","ref":"PubSubx.html#publish/3"},{"type":"function","title":"PubSubx.start_link/1","doc":"Starts the `PubSubx` server.","ref":"PubSubx.html#start_link/1"},{"type":"function","title":"Options - PubSubx.start_link/1","doc":"- `:name` - The name to register the `GenServer` under (default: `PubSubx`).\n  - `:registry_name` - Option to possible change the inner registry name.\n  - `:registry_partitions` - Option to possible change the inner registry partitions, default: `System.schedulers_online()`","ref":"PubSubx.html#start_link/1-options"},{"type":"function","title":"PubSubx.subscribe/3","doc":"Subscribes a given process (`pid`) to a specific `topic`.\n\nIf a `name` is not provided, it defaults to the `PubSubx` module name.","ref":"PubSubx.html#subscribe/3"},{"type":"function","title":"PubSubx.subscribers/2","doc":"Returns a list of PIDs that are subscribed to the specified `topic`.\n\nIf a `name` is not provided, it defaults to the `PubSubx` module name.","ref":"PubSubx.html#subscribers/2"},{"type":"function","title":"PubSubx.topics/1","doc":"Lists all topics that have active subscribers.\n\nIf a `name` is not provided, it defaults to the `PubSubx` module name.","ref":"PubSubx.html#topics/1"},{"type":"function","title":"PubSubx.unsubscribe/3","doc":"Unsubscribes a given process (`pid`) from the specified `topic`.\n\nIf a `name` is not provided, it defaults to the `PubSubx` module name.","ref":"PubSubx.html#unsubscribe/3"},{"type":"type","title":"PubSubx.process/0","doc":"","ref":"PubSubx.html#t:process/0"},{"type":"type","title":"PubSubx.topic/0","doc":"","ref":"PubSubx.html#t:topic/0"},{"type":"module","title":"PubSubx.Auto","doc":"Provides a macro to automatically generate common `PubSubx` functionality\nfor a module, including function specifications.","ref":"PubSubx.Auto.html"},{"type":"module","title":"Usage - PubSubx.Auto","doc":"To use this module, include `PubSubx.Auto` in your module and provide the `:name` option:\n\n    defmodule MyPubSub do\n      use PubSubx.Auto, name: MyPubSub\n    end\n\nThis will create functions such as `start_link/0`, `subscribe/2`, `publish/2`, etc., with specifications that use the provided `name` for `PubSubx` operations.","ref":"PubSubx.Auto.html#module-usage"},{"type":"module","title":"Functions - PubSubx.Auto","doc":"The following functions are automatically defined in the module:\n\n  - `start_link/0`: Starts the `PubSubx` server with the specified name.\n  - `subscribe/2`: Subscribes a given process to a topic.\n  - `subscribers/1`: Retrieves a list of subscribers for a given topic.\n  - `topics/0`: Lists all topics with at least one subscriber.\n  - `publish/2`: Publishes a message to a given topic.\n  - `unsubscribe/2`: Unsubscribes a given process from a topic.","ref":"PubSubx.Auto.html#module-functions"},{"type":"extras","title":"PubSubx","doc":"# PubSubx\n\n`PubSubx` is a lightweight and flexible publish-subscribe (PubSub) library built on top of Elixir's `GenServer` and `Registry`. It allows processes to communicate by subscribing to topics and receiving messages when they are published. This is useful for decoupling components in your Elixir applications, enabling easier scalability and maintainability.","ref":"readme.html"},{"type":"extras","title":"Features - PubSubx","doc":"- **Subscribe/Unsubscribe**: Processes can easily subscribe or unsubscribe from topics.\n- **Publish**: Messages can be published to any topic, notifying all subscribed processes.\n- **Dynamic Topic Management**: Topics are created and removed dynamically based on subscriptions.\n- **Process Monitoring**: Automatically handles the removal of subscriptions when processes terminate.","ref":"readme.html#features"},{"type":"extras","title":"Installation - PubSubx","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed by adding `pub_subx` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:pub_subx, \"~> 0.2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - PubSubx","doc":"The docs can be found at  .","ref":"readme.html#usage"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.2.1] - 2024-09-01","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Registry options in start_link args\n\n## [0.2.0] - 2024-09-01","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- PubSubx methods to specify pubsub process at first","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- PubSubx.Auto mod for easier usage\n- more docs\n\n\n## [0.1.2] - 2024-09-01","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Comprehensive module documentation for `PubSubx`, including detailed explanations of functions and usage examples.\n- A `README.md` with an overview of the project, installation instructions, usage examples, and contribution guidelines.\n- A `CHANGELOG.md` to track changes to the project.\n\n## [0.1.1] - 2022-12-02","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Initial implementation of the `PubSubx` library, providing basic publish-subscribe functionality.\n- Core features:\n  - Topic subscription and unsubscription.\n  - Message publishing to topics.\n  - Listing of subscribers and topics.\n  - Automatic cleanup of subscriptions when processes terminate.","ref":"changelog.html#added"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}